{% extends "admin/base_site.html" %}
{% block extrastyle %}
{% if ENVIRONMENT_NAME and ENVIRONMENT_COLOR %}
<!-- Environment notice -->
<style type="text/css">
    {{ ENVIRONMENT_ADMIN_SELECTOR}}:before {
        display: block;
        line-height: 35px;
        text-align: center;
        font-weight: bold;
        text-transform: uppercase;
        color: white;
        content: "{{ ENVIRONMENT_NAME }}";
        background-color: {{ ENVIRONMENT_COLOR }};
    }
{% endif %}
</style>
{% endblock %}
